@@ -260,7 +260,7 @@ static void day_view_edit_meeting_cb(day_win *dw, gpointer data_i, gpointer data
 static void day_view_cancel_meeting_cb(day_win *dw, gpointer data_i, gpointer data_s)
 {
 	const gchar *uid = (gchar *)data_s;
-	vcalendar_cancel_meeting(uid);
+	vcalendar_cancel_meeting(dw->item, uid);
 }
 
 static void day_view_today_cb(day_win *dw, gpointer data_i, gpointer data_s)
