@@ -312,6 +312,9 @@ static void vcal_item_opened(FolderItem *item)
 
 void vcal_folder_refresh_cal(FolderItem *item)
 {
+	Folder *folder = folder_find_from_name ("vCalendar", vcal_folder_get_class());
+	if (item->folder != folder)
+		return;
 	if (((VCalFolderItem *)(item))->dw)
 		refresh_day_win(((VCalFolderItem *)(item))->dw);
 	if (((VCalFolderItem *)(item))->mw)
@@ -424,6 +427,7 @@ static FolderItem *vcal_item_new(Folder *folder)
 {
 	VCalFolderItem *item;
 	item = g_new0(VCalFolderItem, 1);
+	item->use_cal_view = 1;
 	return (FolderItem *) item;
 
 }
@@ -715,7 +719,7 @@ GSList *vcal_get_events_list(FolderItem *item)
 			continue;
 		if (event->rec_occurence) {
 			vcal_manager_free_event(event);
-			g_unlink(d->d_name);
+			claws_unlink(d->d_name);
 			continue;
 		}
 
@@ -917,6 +921,9 @@ static gchar *feed_fetch_item(FolderItem * fitem, gint num)
 	int i = 1;
 	IcalFeedData *data = NULL;
 
+	if (!item->numlist) {
+		folder_item_scan_full(fitem, FALSE);
+	}	
 	if (!item->numlist) {
 		debug_print("numlist null\n");
 		return NULL;
@@ -1657,7 +1664,7 @@ gboolean vcal_curl_put(gchar *url, FILE *fp, gint filesize, const gchar *user, c
 
 	curl_easy_getinfo(curl_ctx, CURLINFO_RESPONSE_CODE, &response_code);
 	if (response_code < 200 || response_code >= 300) {
-		g_warning("Can't export calendar, got code %d\n", response_code);
+		g_warning("Can't export calendar, got code %ld\n", response_code);
 		res = FALSE;
 	}
 	curl_easy_cleanup(curl_ctx);
